@echo off
SETLOCAL
::########################################################################
::# Licensed Materials - Property of IBM                                 #
::#                                                                      #
::# IBM Content Manager for Multiplatforms V8 (program number 5724-B19)  #
::# (c) Copyright IBM Corp. 1994, 2009.  All Rights Reserved.            #
::#                                                                      #
::# US Government Users Restricted Rights -                              #
::# Use, duplication or disclosure restricted by GSA ADP Schedule        #
::# Contract with IBM Corporation                                        #
::#                                                                      #
::# Start Resource Manager/Volume Validation Utility                     #
::#                                                                      #
::# Program name   : icmrmlsval.bat (WIN NT batch script)                #
::#                                                                      #
::# Description    : This script is to be used by an administrator in    #
::#                  order to get a report of objects registered in      #
::#                  the Resource Manager that do not exist on the       #
::#                  Library Server, that exist on the Library serve     #
::#                  and not on the RM, or any objects that have size,   #
::#                  date, or collection mismatches.                     #
::#                  This script also cleans up the external object name #
::#                  in the library server tables.                       #
::#                                                                      #
::#  Usage:icmrmlsval.bat                                                #
::#      <-db dbname>    <-app rmappname>     <-node nodename>           #
::#      <-was was_home> <-insthome isnthome> <-orajdbc ora_jdbc_abspath>#
::#    where:                                                            #
::#      dbname       --> Resource Manager Database Name                 #
::#      rmappname    --> Resource Manager Application Name              #
::#      nodename     --> If using WAS5.x, set the WAS nodename          #
::#      was_home     --> WebSphere home installation directory          #
::#      insthome     --> db2 instance home use for RM install           #
::#      ora_jdbc_abspath --> If RM DB is an Oracle database set Oracle's#
::#                       JDBC fully qualify file name (ojdbc14.jar)     #
::#                       PREREQ: Oracle's JDBC 9.2.0.X                  #
::# If icmrmlsval.bat is call without arguments the values specified     #
::#       in $IBMCMROOT/config/setprocenv390.bat are use.                #
::#                                                                      #
::########################################################################

set caller_script=icmrmlsval390.bat
set CURRENT_DIR=%CD%
::################### RUNNING VALIDATION UTILITY ##############################
:run

::# Ensure JAVA_HOME is set.  If not, notify user
IF "%JAVA_HOME%" == "" (
   echo The JAVA_HOME variable in Windows is not set.  Refer to the zOSValidator.readme.pdf for instructions.
   GOTO end
)

set CLASSPATH="%CURRENT_DIR%;%CURRENT_DIR%\jar\NLVLog.jar;%CURRENT_DIR%\jar\log4j-1.2.8.jar;.;%CURRENT_DIR%\jar\xalan.jar;%CURRENT_DIR%\jar\xerces.jar;%CURRENT_DIR%\jar\j2ee.jar;%JAVA_HOME%\jre\lib\ext\ibmjceprovider.jar;%JAVA_HOME%\jre\lib\ext\ibmjcefw.jar;%CURRENT_DIR%\jar\db2java.zip;%CURRENT_DIR%\jar\db2jcc_license_cisuz.jar"
 
set FULLPATH="%CURRENT_DIR%"

IF NOT EXIST "%CURRENT_DIR%\rmutil_common390.bat" goto rmconfigerr
call "%CURRENT_DIR%\rmutil_common390.bat" %caller_script% %*

IF DEFINED HELP (exit /b 0)

"%JAVA_HOME%\bin\java.exe" NLVLog ICMRM COPYRIGHT
IF NOT EXIST %FULLPATH% goto rmdeployerr
IF "%begin%" == "" GOTO NEXTOPT
set PARAMS=-b %begin%
:NEXTOPT
IF "%end%" == "" GOTO NEXTOPT
set PARAMS=%PARAMS% -e %end%
:NEXTOPT
IF "%logfile%" == "" GOTO NEXTOPT
set PARAMS=%PARAMS% -f %logfile%
:NEXTOPT
IF "%lsuid%" == "" GOTO NEXTOPT
set PARAMS=%PARAMS% -l %lsuid%
:NEXTOPT
IF "%lspwd%" == "" GOTO NEXTOPT
set PARAMS=%PARAMS% -w %lspwd%
:NEXTOPT
IF "%rmuid%" == "" GOTO NEXTOPT
set PARAMS=%PARAMS% -r %rmuid%
:NEXTOPT
IF "%rmpwd%" == "" GOTO NEXTOPT
set PARAMS=%PARAMS% -p %rmpwd%
:NEXTOPT
IF "%cleanup%" == "" GOTO NEXTOPT
set PARAMS=%PARAMS% -c %cleanup%
:NEXTOPT
IF "%rmvalhelp%" == "" GOTO CONTINUE 
set PARAMS=-h %rmvalhelp%
:CONTINUE
echo %PARAMS%
cd /d %FULLPATH%
"%JAVA_HOME%\bin\java.exe" -DIBMCMROOT="%CURRENT_DIR%" com.ibm.mm.icmrm.process.RMLSValidator390 %PARAMS%
goto end

:rmdeployerr
"%JAVA_HOME%\bin\java.exe" NLVLog ICMRM RM_DEPLOY_DIR_PROBLEM 
"%JAVA_HOME%\bin\java.exe" NLVLog ICMRM RM_DEPLOY_APP_PROBLEM
goto end

:rmconfigerr
"%JAVA_HOME%\bin\java.exe" NLVLog ICMRM ICMRM FILE_NOT_FOUND "%CURRENT_DIR%\rmutil_common390.bat"
goto end

:end
ENDLOCAL
@echo off
