::##############################################################################
::# Licensed Materials - Property of IBM                                       #
::#                                                                            #
::# IBM Content Manager for Multiplatforms V8.2 (program number 5724-B19)      #
::# (c) Copyright IBM Corp. 1994,2002,2003.                                    #
::#                                                                            #
::# US Government Users Restricted Rights -                                    #
::# Use, duplication or disclosure restricted by GSA ADP Schedule              #
::# Contract with IBM Corporation                                              #
::#                                                                            #
::##############################################################################
@ECHO OFF
set CURRENT_DIR=%CD%

::# to enable debug printing messages, uncomment the following
::set RMDEBUG=1

::# uncomment to print the environment variables
::# 'set' is hidden in a variable otherwise 'batch' always run it even if there's a IF statement.
set RUN_SET=set

::# set a temprary JAVA until WAS location is known (re is always shipped in CM8.3)
set JAVA="%JAVA_HOME%\bin\java.exe"

set PRINT_MSG=%JAVA% NLVLog ICMRM


::# prints initial environement for debug
IF DEFINED RMDEBUG (
	@echo --------------------
	@echo environment before 
	@echo --------------------
	IF DEFINED RUN_SET (
		REM print environment by calling set
		%RUN_SET%
	)
	echo --- end printing environment before ---
)
::############################################################
::# set caller script and remove the 1st parameter (caller_script)
::############################################################
set caller_script=%1
IF DEFINED RMDEBUG (
	@echo caller_script is %caller_script%
	@echo shifting parameters..
)
shift

::############################################################
::# call setprocenv390.bat to set the variables set by setprocenv390
::############################################################
IF EXIST "%CURRENT_DIR%\setprocenv390.bat" (
	call "%CURRENT_DIR%\setprocenv390.bat"
) ELSE (
	REM	echo "ICM9748: File %CURRENT_DIR%\setprocenv390.bat cannot be found."
	%PRINT_MSG% FILE_NOT_FOUND "%CURRENT_DIR%\setprocenv390.bat"
	exit /B 9748
)

IF DEFINED RMDEBUG (
	echo -----------------------------
	echo environment after setprocenv390
	echo ------------------------------
	IF DEFINED RUN_SET (
		REM print environment by calling set
		%RUN_SET%
	)
	echo --- end printing environment after setprocenv390 ---
)

::##########################################################
::# Parsing parameters
::##########################################################

IF DEFINED RMDEBUG  @echo param1 = %1

::# detecting request for help
IF "%1" == "" GOTO PRINT_HELP
IF "%1" == "/?" GOTO PRINT_HELP
IF "%1" == "/h" GOTO PRINT_HELP
IF "%1" == "-h" GOTO PRINT_HELP
IF "%1" == "-help" GOTO PRINT_HELP
IF "%1" == "--help" GOTO PRINT_HELP

::# detecting of positionnal parameter : $1=start|stop
IF "%1" == "start" GOTO POSITIONAL_PARAMS
IF "%1" == "stop" GOTO POSITIONAL_PARAMS

::# else parse as named parameters


::##########################################################
::# parse named parameters set from command lines
::# <command> -param1 value1 -param2 value2
::##########################################################

:WHILE_NAMED_PARAMS

::# if done, there won't be any variable to read, exit the loop
IF "%1" == "" GOTO CONTINUE

::# processing parameters by pair at each loop
IF DEFINED RMDEBUG (
	@echo current_param = %1
	@echo current_value = %2
)

::# set a parameter to see if the variable have been parsed
set FOUND_PARAM=0

::# this will read each line of rmvars390.list
::# and assign to %%a %%b %%c %%d %%e %%f %%g %%h %%i the values of the line (separated by ':')
::# assuming 8 is the max nb of possible paramaters (%%b, %%c, %%d, %%e, %%f, %%g, %%h, %%i)
::# ex: variable 'volume' can be set with  -v, -V, /v, /V
FOR /F "eol=# tokens=1,2,3,4,5,6,7,8,9 delims=:" %%a in (rmvars390.list) DO (

	REM rmvars390.list has each line 
	REM following this syntax:  varname:param:param:param
	REM Example: dbname:-db:-dbname
	IF DEFINED RMDEBUG (
		@echo variable name : %%a
		@echo external param 1 : %%b
		@echo external param 2 : %%c
		@echo external param 3 : %%d
		@echo external param 4 : %%e
		@echo external param 5 : %%f
		@echo external param 6 : %%g
		@echo external param 7 : %%h
		@echo external param 8 : %%i
	)

	REM try to find a match for the current_param
	REM when found, set variable named "%%a" to the current_value %2
	REM Example : "%%a" = "dbname"   and "%2" = RMDB
	IF "%1" == "%%b" (
		set %%a=%2
		set FOUND_PARAM=1
	)
	IF "%1" == "%%c" (
		set %%a=%2
		set FOUND_PARAM=1
	)
	IF "%1" == "%%d" (
		set %%a=%2
		set FOUND_PARAM=1
	)
	IF "%1" == "%%e" (
		set %%a=%2
		set FOUND_PARAM=1
	)
	IF "%1" == "%%f" (
		set %%a=%2
		set FOUND_PARAM=1
	)
	IF "%1" == "%%g" (
		set %%a=%2
		set FOUND_PARAM=1
	)
	IF "%1" == "%%h" (
		set %%a=%2
		set FOUND_PARAM=1
	)
	IF "%1" == "%%i" (
		set %%a=%2
		set FOUND_PARAM=1
	)
)

::# if the param has not been parsed, it means it's invalid
IF "%FOUND_PARAM%"=="0" (
	REM @echo "ERROR: ICM9976: Please check and ensure that the %1 parameter is set correctly."
	%PRINT_MSG% CONFIG_PARAM_INVALID %1
	goto PRINT_HELP_EXIT_WITH_ERROR
)

::# shifting by 2 for next loop
shift
shift
goto WHILE_NAMED_PARAMS

::##########################################################
::# parse positional parameters set from command lines
::# <command> -param1 value1 -param2 value2
::##########################################################

:POSITIONAL_PARAMS
echo WARN: POSITIONAL INPUT PARAMETERS SYNTAX IS DEPRECATED
set procAction=%1
set dbname=%2
set rmappname=%3
set process=%4

:CONTINUE

::#######################################################
::# prints a summary of variables set from command line
::#######################################################
IF DEFINED RMDEBUG (
	echo ---------------------------------
	echo variables set from command line
	echo ---------------------------------
	REM for each variable name listed in rmvars390.list	
	FOR /F "eol=# delims=: tokens=1" %%i IN (rmvars390.list) DO (
	
		REM	parse the result of the command 'set <variable_name>'
		REM result is : <variable_name>=<value>
		REM and so we just print the part after '='
		IF DEFINED %%i (
			FOR /F "usebackq delims== tokens=2" %%j IN (`set %%i`) DO (
				@echo %%i=%%j
			)
		) ELSE (
			@echo %%i=
		)
	)
)

::################################################################
::## done parsing parameters, 
::## now get the information from variables set in setprocenv390.bat
::################################################################

::# define "rm" if not set -- pick from dbname and appname ---
IF NOT DEFINED rmname (
	REM rmname=<dbname>
	IF DEFINED dbname (
		set rmname=%dbname%
	) ELSE (
		IF DEFINED default_rmname (
		set rmname=%default_rmname%
		) ELSE (
			goto error_rm_cannot_be_defined
		)
	)
)
REM @echo rmname=%rmname%

::# set params listed in rmvars390.list from env. vars set in setproenv
FOR /F "eol=# delims=: tokens=1" %%i IN (rmvars390.list) DO (

	IF DEFINED RMDEBUG @echo current rmvar: i=%%i

::	# we don't do anything if the variable is already set	
	IF NOT DEFINED %%i (
		REM 1. run `set <rmname>_variablename` 
		REM 2. returns : <rmname>_<variablename>=<value>
		REM 3. store <value> in %%j 
		REM 4. set the <variable_name> with %%j
		FOR /F "usebackq delims== tokens=2" %%j IN (`if defined %rmname%_%%i set %rmname%_%%i`) DO (
		    IF DEFINED RMDEBUG @echo current value: j=%%j
			set %%i=%%j
		)
	)
)

::####################################
::# prints a summary of variables set 
::####################################
if DEFINED RMDEBUG (
	echo ---------------------------------
	echo RM variables
	echo ---------------------------------
	FOR /F "eol=# delims=: tokens=1" %%i IN (rmvars390.list) DO (
		IF DEFINED RMDEBUG @echo "print variable : i=%%i"
		IF DEFINED %%i (
			set %%i
		) ELSE (
			@echo %%i=
		)
	)
)
::# done parsing parameters

::# to test if the parsing is all working, 
::# 1.uncomment the 'exit' statement below
::# 2. run  "setrmvars.bat -db dbname -app rmappname"  to see how we take from setprocenv390
::#    run  "setrmvars.bat -act start -db dbname -app rmappname -v volume " to see how we take from setprocenv390
::#    run  "setrmvars.bat start dbname rmappname RMMigrator" to see the positionnal parameter
::#exit

::################################################################
::## prepare the environment for the RM services/utilities execution
::################################################################

:SETENV

GOTO setjdbc

:setjdbc
::IF DEFINED RMDEBUG @echo db2home=%db2home%
::IF NOT EXIST "%db2home%" (
::	echo "ERROR db2home [%db2home%] does not exist" 
::) ELSE (
::	set CLASSPATH=%CLASSPATH%;%db2home%\java\db2java.zip
::)

GOTO END


:: ######## Print Usage #########

:PRINT_HELP
IF DEFINED RMDEBUG (
	@echo calling "%JAVA% RMUtilHelp %caller_script%"
)
%JAVA% RMUtilHelp %caller_script%
set HELP=1
exit /b 0

:PRINT_HELP_EXIT_WITH_ERROR
IF DEFINED RMDEBUG (
	@echo calling java RMUtilHelp %caller_script%
)
%JAVA% RMUtilHelp %caller_script%
exit /b 1

::######## ERRORS #########

:error_rm_cannot_be_defined
echo ERROR RM information need to be provided with -rm dbname or -db dbname
goto END

:END
IF DEFINED RMDEBUG (
	echo -----------------------------
	echo environment exiting setrmvars
	echo -----------------------------
	IF DEFINED RUN_SET (
		REM print environment by calling set
		%RUN_SET%
	)
	echo --- end printing environment exiting setrmvars ---
)
cd /d "%CURRENT_DIR%"